# Inspired Cognition API Client

This is the API client to [Inspired Cognition](https://inspiredco.ai) services.

## Getting Started

To install the client, make sure you have Python 3.8 or higher, and then run the
following command:

```shell
pip install inspiredco
```

To use the API, you will need an API key. You can obtain one by traveling to the
[Inspired Cognition Dashboard](https://dashboard.inspiredco.ai).

## Usage

See the documentation at the links below for more detailed usage.

* [Critique](https://docs.inspiredco.ai/critique/)
